@@ -22,6 +22,8 @@ package org.apache.cxf.jaxrs.provider;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.io.Reader;
+import java.io.Writer;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;
 import java.util.Arrays;
@@ -44,7 +46,6 @@ import javax.ws.rs.ext.Provider;
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
 import javax.xml.bind.Marshaller;
-import javax.xml.bind.PropertyException;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
 import javax.xml.namespace.QName;
@@ -56,8 +57,8 @@ import javax.xml.stream.XMLStreamWriter;
 import javax.xml.transform.Source;
 
 import org.apache.cxf.helpers.CastUtils;
-import org.apache.cxf.jaxb.NamespaceMapper;
 import org.apache.cxf.jaxrs.ext.MessageContext;
+import org.apache.cxf.jaxrs.ext.Nullable;
 import org.apache.cxf.jaxrs.ext.xml.XMLInstruction;
 import org.apache.cxf.jaxrs.ext.xml.XMLSource;
 import org.apache.cxf.jaxrs.ext.xml.XSISchemaLocation;
@@ -68,16 +69,15 @@ import org.apache.cxf.jaxrs.utils.JAXBUtils;
 import org.apache.cxf.jaxrs.utils.schemas.SchemaHandler;
 import org.apache.cxf.message.Attachment;
 import org.apache.cxf.message.Message;
+import org.apache.cxf.staxutils.DepthExceededStaxException;
 import org.apache.cxf.staxutils.StaxUtils;
 import org.apache.cxf.staxutils.transform.TransformUtils;
 
 @Produces({"application/xml", "application/*+xml", "text/xml" })
 @Consumes({"application/xml", "application/*+xml", "text/xml" })
 @Provider
-public class JAXBElementProvider extends AbstractJAXBProvider  {
+public class JAXBElementProvider<T> extends AbstractJAXBProvider<T>  {
     private static final String XML_PI_START = "<?xml version=\"1.0\" encoding=\"";
-    private static final String NS_MAPPER_PROPERTY = "com.sun.xml.bind.namespacePrefixMapper";
-    private static final String NS_MAPPER_PROPERTY_INT = "com.sun.xml.internal.bind.namespacePrefixMapper";
     private static final String XML_PI_PROPERTY = "com.sun.xml.bind.xmlHeaders";
     private static final String XML_PI_PROPERTY_INT = "com.sun.xml.internal.bind.xmlHeaders";
     
@@ -147,13 +147,19 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         mProperties.put(Marshaller.JAXB_SCHEMA_LOCATION, schemaLocation);
     }
     
-    public Object readFrom(Class<Object> type, Type genericType, Annotation[] anns, MediaType mt, 
+    public T readFrom(Class<T> type, Type genericType, Annotation[] anns, MediaType mt, 
         MultivaluedMap<String, String> headers, InputStream is) 
         throws IOException {
+        if (isPayloadEmpty()) {
+            if (AnnotationUtils.getAnnotation(anns, Nullable.class) != null) {
+                return null;
+            } else {
+                reportEmptyContentLength();
+            }
+        }
+        
         try {
             
-            checkContentLength();
-            
             boolean isCollection = InjectionUtils.isSupportedCollectionOrArray(type);
             Class<?> theGenericType = isCollection ? InjectionUtils.getActualType(genericType) : type;
             Class<?> theType = getActualType(theGenericType, genericType, anns);
@@ -172,7 +178,7 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
                 response = doUnmarshal(unmarshaller, type, is, mt);
             }
             if (response instanceof JAXBElement && !JAXBElement.class.isAssignableFrom(type)) {
-                response = ((JAXBElement)response).getValue();    
+                response = ((JAXBElement<?>)response).getValue();    
             }
             if (isCollection) {
                 response = ((CollectionWrapper)response).getCollectionOrArray(theType, type, 
@@ -180,15 +186,17 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
             } else {
                 response = checkAdapter(response, type, anns, false);
             }
-            return response;
+            return type.cast(response);
             
         } catch (JAXBException e) {
             handleJAXBException(e, true);
+        } catch (DepthExceededStaxException e) {
+            throw new WebApplicationException(413);
         } catch (WebApplicationException e) {
             throw e;
         } catch (Exception e) {
             LOG.warning(getStackTrace(e));
-            throw new WebApplicationException(e);        
+            throw new WebApplicationException(e, Response.status(400).build());        
         }
         // unreachable
         return null;
@@ -219,10 +227,11 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         }
         
         if (reader == null && is == null) {
-            reader = getStaxHandlerFromCurrentMessage(XMLStreamReader.class);
+            reader = getStreamHandlerFromCurrentMessage(XMLStreamReader.class);
         }
         
         reader = createTransformReaderIfNeeded(reader, is);
+        reader = createDepthReaderIfNeeded(reader, is);
         if (InjectionUtils.isSupportedCollectionOrArray(type)) {
             return new JAXBCollectionWrapperReader(TransformUtils.createNewReaderIfNeeded(reader, is));
         } else {
@@ -234,7 +243,16 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
     protected Object unmarshalFromInputStream(Unmarshaller unmarshaller, InputStream is, MediaType mt) 
         throws JAXBException {
         // Try to create the read before unmarshalling the stream
-        return unmarshaller.unmarshal(StaxUtils.createXMLStreamReader(is));
+        if (is == null) {
+            Reader reader = getStreamHandlerFromCurrentMessage(Reader.class);
+            if (reader == null) {
+                LOG.severe("No InputStream, Reader, or XMStreamReader is available");
+                throw new WebApplicationException(500);
+            }
+            return unmarshaller.unmarshal(StaxUtils.createXMLStreamReader(reader));
+        } else {
+            return unmarshaller.unmarshal(StaxUtils.createXMLStreamReader(is));
+        }
     }
 
     protected Object unmarshalFromReader(Unmarshaller unmarshaller, XMLStreamReader reader, MediaType mt) 
@@ -242,7 +260,7 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         return unmarshaller.unmarshal(reader);
     }
     
-    public void writeTo(Object obj, Class<?> cls, Type genericType, Annotation[] anns,  
+    public void writeTo(T obj, Class<?> cls, Type genericType, Annotation[] anns,  
         MediaType m, MultivaluedMap<String, Object> headers, OutputStream os) 
         throws IOException {
         try {
@@ -273,16 +291,16 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         Class<?> actualClass = InjectionUtils.getActualType(genericType);
         actualClass = getActualType(actualClass, genericType, anns);
         
-        Collection c = originalCls.isArray() ? Arrays.asList((Object[]) collection) 
-                                             : (Collection) collection;
+        Collection<?> c = originalCls.isArray() ? Arrays.asList((Object[]) collection) 
+                                             : (Collection<?>) collection;
 
-        Iterator it = c.iterator();
+        Iterator<?> it = c.iterator();
         
         Object firstObj = it.hasNext() ? it.next() : null;
 
         QName qname = null;
         if (firstObj instanceof JAXBElement) {
-            JAXBElement el = (JAXBElement)firstObj;
+            JAXBElement<?> el = (JAXBElement<?>)firstObj;
             qname = el.getName();
             actualClass = el.getDeclaredType();
         } else {
@@ -338,7 +356,7 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
                                            String ns) throws Exception {
         
         if (obj instanceof JAXBElement) {
-            obj = ((JAXBElement)obj).getValue();    
+            obj = ((JAXBElement<?>)obj).getValue();    
         } else {
             obj = convertToJaxbElementIfNeeded(obj, cls, genericType);
         }
@@ -361,11 +379,6 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         marshal(obj, cls, genericType, enc, os, mt, ms);
     }
     
-    protected static void setNamespaceMapper(Marshaller ms, Map<String, String> map) throws Exception {
-        NamespaceMapper nsMapper = new NamespaceMapper(map);
-        setMarshallerProp(ms, nsMapper, NS_MAPPER_PROPERTY, NS_MAPPER_PROPERTY_INT);
-    }
-    
     protected void marshal(Object obj, Class<?> cls, Type genericType, 
                            String enc, OutputStream os, MediaType mt) throws Exception {
         marshal(obj, cls, genericType, enc, os, mt, new Annotation[]{});
@@ -429,15 +442,7 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         }
     }
     
-    private static void setMarshallerProp(Marshaller ms, Object value, 
-                                          String name1, String name2) throws Exception {
-        try {
-            ms.setProperty(name1, value);
-        } catch (PropertyException ex) {
-            ms.setProperty(name2, value);
-        }
-        
-    }
+    
     
     protected void addAttachmentMarshaller(Marshaller ms) {
         Collection<Attachment> attachments = getAttachments(true);
@@ -526,14 +531,24 @@ public class JAXBElementProvider extends AbstractJAXBProvider  {
         } 
         
         if (writer == null && os == null) {
-            writer = getStaxHandlerFromCurrentMessage(XMLStreamWriter.class);
+            writer = getStreamHandlerFromCurrentMessage(XMLStreamWriter.class);
         }
         return createTransformWriterIfNeeded(writer, os);
     }
     
     protected void marshalToOutputStream(Marshaller ms, Object obj, OutputStream os, MediaType mt) 
         throws Exception {
-        ms.marshal(obj, os);
+        if (os == null) {
+            Writer writer = getStreamHandlerFromCurrentMessage(Writer.class);
+            if (writer == null) {
+                LOG.severe("No OutputStream, Writer, or XMStreamWriter is available");
+                throw new WebApplicationException(500);
+            }
+            ms.marshal(obj, writer);
+            writer.flush();
+        } else {
+            ms.marshal(obj, os);
+        }
     }
     
     protected void marshalToWriter(Marshaller ms, Object obj, XMLStreamWriter writer, MediaType mt) 
