@@ -50,8 +50,6 @@ import org.apache.cxf.transport.servlet.CXFNonSpringServlet;
 
 public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
 
-    private static final long serialVersionUID = -8916352798780577499L;
-
     private static final Logger LOG = LogUtils.getL7dLogger(CXFNonSpringJaxrsServlet.class);
     
     private static final String USER_MODEL_PARAM = "user.model";
@@ -64,10 +62,8 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
     private static final String SERVICE_SCOPE_PARAM = "jaxrs.scope";
     private static final String EXTENSIONS_PARAM = "jaxrs.extensions";
     private static final String LANGUAGES_PARAM = "jaxrs.languages";
-    private static final String PROPERTIES_PARAM = "jaxrs.properties";
+    private static final String PROPERTIES_PARAM = "jaxrs.languages";
     private static final String SCHEMAS_PARAM = "jaxrs.schemaLocations";
-    private static final String DOC_LOCATION_PARAM = "jaxrs.documentLocation";
-    private static final String STATIC_SUB_RESOLUTION_PARAM = "jaxrs.static.subresources";
     private static final String SERVICE_SCOPE_SINGLETON = "singleton";
     private static final String SERVICE_SCOPE_REQUEST = "prototype";
     
@@ -91,43 +87,31 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
             address = "/";
         }
         bean.setAddress(address);
-        
-        bean.setStaticSubresourceResolution(getStaticSubResolutionValue(servletConfig));
-        
         String modelRef = servletConfig.getInitParameter(USER_MODEL_PARAM);
         if (modelRef != null) {
             bean.setModelRef(modelRef.trim());
         }
-        setDocLocation(bean, servletConfig);
+        
         setSchemasLocations(bean, servletConfig);
         setAllInterceptors(bean, servletConfig);
         
-        Map<Class<?>, Map<String, String>> resourceClasses = 
+        Map<Class, Map<String, String>> resourceClasses = 
             getServiceClasses(servletConfig, modelRef != null);
-        Map<Class<?>, ResourceProvider> resourceProviders = 
+        Map<Class, ResourceProvider> resourceProviders = 
             getResourceProviders(servletConfig, resourceClasses);
         
         List<?> providers = getProviders(servletConfig);
                 
-        bean.setResourceClasses(new ArrayList<Class<?>>(resourceClasses.keySet()));
+        bean.setResourceClasses(new ArrayList<Class>(resourceClasses.keySet()));
         bean.setProviders(providers);
-        for (Map.Entry<Class<?>, ResourceProvider> entry : resourceProviders.entrySet()) {
+        for (Map.Entry<Class, ResourceProvider> entry : resourceProviders.entrySet()) {
             bean.setResourceProvider(entry.getKey(), entry.getValue());
         }
         setExtensions(bean, servletConfig);
-                
+        
         bean.create();
     }
 
-    protected boolean getStaticSubResolutionValue(ServletConfig servletConfig) {
-        String param = servletConfig.getInitParameter(STATIC_SUB_RESOLUTION_PARAM);
-        if (param != null) {
-            return Boolean.valueOf(param.trim());
-        } else {
-            return false;
-        }
-    }
-    
     protected void setExtensions(JAXRSServerFactoryBean bean, ServletConfig servletConfig) {
         bean.setExtensionMappings(handleMapSequence(servletConfig.getInitParameter(EXTENSIONS_PARAM)));
         bean.setLanguageMappings(handleMapSequence(servletConfig.getInitParameter(LANGUAGES_PARAM)));
@@ -176,13 +160,6 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
         }
     }
     
-    protected void setDocLocation(JAXRSServerFactoryBean bean, ServletConfig servletConfig) {
-        String wadlLoc = servletConfig.getInitParameter(DOC_LOCATION_PARAM);
-        if (wadlLoc != null) {
-            bean.setDocLocation(wadlLoc);
-        }
-    }
-    
     @SuppressWarnings("unchecked")
     protected void setInterceptors(JAXRSServerFactoryBean bean, ServletConfig servletConfig,
                                    String paramName) {
@@ -223,7 +200,7 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
         }
     }
     
-    protected Map<Class<?>, Map<String, String>> getServiceClasses(ServletConfig servletConfig,
+    protected Map<Class, Map<String, String>> getServiceClasses(ServletConfig servletConfig,
                                             boolean modelAvailable) throws ServletException {
         String serviceBeans = servletConfig.getInitParameter(SERVICE_CLASSES_PARAM);
         if (serviceBeans == null) {
@@ -233,7 +210,7 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
             throw new ServletException("At least one resource class should be specified");
         }
         String[] classNames = serviceBeans.split(" ");
-        Map<Class<?>, Map<String, String>> map = new HashMap<Class<?>, Map<String, String>>();
+        Map<Class, Map<String, String>> map = new HashMap<Class, Map<String, String>>();
         for (String cName : classNames) {
             Map<String, String> props = new HashMap<String, String>();
             String theName = getClassNameAndProperties(cName, props);
@@ -277,16 +254,16 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
         return theName;
     }
     
-    protected Map<Class<?>, ResourceProvider> getResourceProviders(ServletConfig servletConfig,
-            Map<Class<?>, Map<String, String>> resourceClasses) throws ServletException {
+    protected Map<Class, ResourceProvider> getResourceProviders(ServletConfig servletConfig,
+            Map<Class, Map<String, String>> resourceClasses) throws ServletException {
         String scope = servletConfig.getInitParameter(SERVICE_SCOPE_PARAM);
         if (scope != null && !SERVICE_SCOPE_SINGLETON.equals(scope)
             && !SERVICE_SCOPE_REQUEST.equals(scope)) {
             throw new ServletException("Only singleton and prototype scopes are supported");
         }
         boolean isPrototype = SERVICE_SCOPE_REQUEST.equals(scope);
-        Map<Class<?>, ResourceProvider> map = new HashMap<Class<?>, ResourceProvider>();
-        for (Map.Entry<Class<?>, Map<String, String>> entry : resourceClasses.entrySet()) {
+        Map<Class, ResourceProvider> map = new HashMap<Class, ResourceProvider>();
+        for (Map.Entry<Class, Map<String, String>> entry : resourceClasses.entrySet()) {
             Class<?> c = entry.getKey();
             map.put(c, isPrototype ? new PerRequestResourceProvider(c)
                                    : new SingletonResourceProvider(
@@ -299,7 +276,7 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
     
     protected Object createSingletonInstance(Class<?> cls, Map<String, String> props, ServletConfig sc) 
         throws ServletException {
-        Constructor<?> c = ResourceUtils.findResourceConstructor(cls, false);
+        Constructor c = ResourceUtils.findResourceConstructor(cls, false);
         if (c == null) {
             throw new ServletException("No valid constructor found for " + cls.getName());
         }
@@ -369,14 +346,10 @@ public class CXFNonSpringJaxrsServlet extends CXFNonSpringServlet {
         Application app = (Application)createSingletonInstance(appClass, props, servletConfig);
         
         String ignoreParam = servletConfig.getInitParameter(IGNORE_APP_PATH_PARAM);
-        JAXRSServerFactoryBean bean = ResourceUtils.createApplication(app, 
-                                            MessageUtils.isTrue(ignoreParam),
-                                            getStaticSubResolutionValue(servletConfig));
+        JAXRSServerFactoryBean bean = ResourceUtils.createApplication(app, MessageUtils.isTrue(ignoreParam));
         setAllInterceptors(bean, servletConfig);
         setExtensions(bean, servletConfig);
-        setDocLocation(bean, servletConfig);
         setSchemasLocations(bean, servletConfig);
-        
         bean.setBus(getBus());
         bean.create();
     }
